
**** This file is to get the right data format for estimation. ************

**** Jia Yan, Dec. 03, 2004
 
clear all
set more off
set mem 400m

********* First to aggregate multi-observations of Brookings RP data ********
use econometrica_br.dta, clear

quietly {
	sort id
	by id: gen n=_n
	by id: gen num=_N
	by id: egen mroute = mean(route)
	
	*** Creating dependent variable based on the percentage of choosing express lanes 
	*** across different days 
	gen ochoice=.
	replace ochoice=1 if mroute < 0.5
	replace ochoice=2 if mroute >= 0.5
	
	*** Averaging the toll, time, and time uncertainty across days
	by id: egen double atime  = mean(median)
	by id: egen double admp   = mean(dmp80)
	by id: egen double adist  = mean(distance)
	by id: egen double acost  = mean(toll)
	by id: egen double adlate = mean(flexibility)
	
	replace median = atime
	replace distance = adist
	replace dmp80 = admp
	replace toll = acost
	replace flexibility = adlate

	keep if n == 1
	*** We assume a person has arrival flexibility if he can arrive late on at least one day.  
	replace flexibility = 1 if flexibility > 0
  	
	drop route mroute n num atime admp adist acost adlate
	rename ochoice route
	replace route=0 if route==1
	replace route=1 if route==2
}
******************* Append with Calpoly data to get the RP data set **********
append using econometrica_cal
sort id

** Expand to long-format **
expand 2
sort id
by id: gen choice = _n
gen y = 0
replace y = 1 if choice == 1 & route == 0 
replace y = 1 if choice == 2 & route == 1

gen express = (choice == 2)

# delimit ;

global vlist "toll median dmp80 female flexibility age3050 householdsize";

# delimit cr

foreach var of global vlist {
	replace `var' = `var' * express
}

keep id choice y express $vlist dist high_income med_income commute brook calpoly
gen rp = 1
sort id
save junk, replace
******************** To get the SP data *************************
use econometrica_bs, clear
rename route y
gen ll = (average_commute_time > 45)
gen ss = (average_commute_time <= 45)
drop average_commute_time
gen sp = 1
gen express = 1
gen choice = 0
****************** To get the full data set **********************
append using junk
replace distance = distance / 10
replace calpoly = 0 if calpoly == .
replace brook = 0 if brook == .
replace sp = 0 if sp == .
replace rp = 0 if rp == .
replace ll = 0 if ll == . 
replace ss = 0 if ss == .


********* Creating Variables ********************
gen express_br = express * brook
gen express_cal = express * calpoly
gen express_sp = express * sp
gen toll_rp = toll * rp
gen toll_sp = toll * sp
gen dmp80_rp = dmp80 * rp
gen dmp80_sp = dmp80 * sp 
gen dtime = distance * median * rp
gen dtime2 = median * distance^2 * rp
gen dtime3 = median * distance^3 * rp
gen hc_rp = high_income * toll * rp
gen mc_rp = med_income * toll * rp
gen hc_sp = high_income * toll * sp
gen mc_sp = med_income * toll * sp
gen lltime = ll * median * sp
gen sstime = ss * median * sp

# delimit ;

global xfixed "express_br express_cal toll_rp hc_rp mc_rp dtime dtime2 dtime3 dmp80_rp
               toll_sp hc_sp mc_sp sstime lltime dmp80_sp
               female flexibility age3050 householdsize express_sp";
               
global xrandom "express_sp median dmp80 express";

# delimit cr

*** Grouping observations based on perosn id. If a perosn has both RP and SP
*** observations, place RP ones before the SP ones
sort id sp choice
outsheet id choice y $xfixed $xrandom brook calpoly rp sp using mydata1.txt, noname replace 

gen weights = 1
by id: gen times = _N
by id: egen srp = sum(rp)
by id: egen ssp = sum(sp)
gen datakinds = 0
replace datakinds = 1 if ssp > 0 & srp == 0
replace datakinds = 2 if srp > 0 & ssp == 0
replace datakinds = 3 if srp > 0 & ssp > 0 

egen tag = tag(id)
keep if tag
sort id
outsheet times weights datakinds using mydata2.txt, noname replace



