function [f] = likelihood(beta)
% This function calculates simulated likelihood function for mixed logit
% model

% Declare global variables
global REPTITION NUSERS CHOICE YVEC XFIXED XRANDOM NFC NNC NALT WEIGHTS...
       RCOEFFS HALTON NERROR RPDATA1 RPDATA2 SP RP TIMES DATAKINDS;  

%% Partition the beta %%
bfixed = beta(1:NFC);
brandom = beta( (NFC + 1) : (NFC + RCOEFFS) );
bscale = beta( (NFC + RCOEFFS + 1) : length(beta));
fix = XFIXED * bfixed;

%% Start to do Monte-Carlo integration %%
pn = zeros(NUSERS,1);
inter = zeros(NUSERS,1);
[r,c] = size(XRANDOM);

for i=1:REPTITION;
	x = zeros(r,c);
	count = 0;
	%% Interact the random variables with random draws %%
	for j = 1:NNC;
    		g = count + i;
    		x(:,j) = XRANDOM(:,j) .* NERROR(:,g);
		count = count + REPTITION;
    	end;	 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   
   	%% Here should be changed based your own model specification %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%   	
   	%% The following specification is for our paper, which has two specialties:
   	%% 1. the specification on the random component of unreliability;
   	%% 2. the correlation between RP and SP choice. 
    	index = fix + brandom(1) * x(:,1) + brandom(2) * x(:,2) + ...
       	  	bfixed(9) * brandom(3) * (RP .* x(:,3)) + ...
    		bfixed(15) * brandom(3) * (SP .* x(:,3)) + ...
    		RP .* x(:,4) + brandom(4) * (SP .* x(:,4));
     	
     	%% Resacling: normalizing RPDATA1 (BR), and rescale the other two %%	
    	index = RPDATA1 .* index + bscale(1) * (RPDATA2 .* index) + ...
	    	bscale(2) * (SP .* index); 	    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     %% You do not need to change the following part %%
     %% Calculate conditional choice probability person by person %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    	ini = 0;
    	for j=1:(NUSERS);
    		if DATAKINDS(j) == 1
   	 		% This case means that this person has only SP observations
    			inter(j) = 1;
    			for k = 1 : TIMES(j);
       				index(ini+k) = exp(-1*index(ini+k));
       				if YVEC(ini+k) == 1
       					inter(j) = inter(j)/(1+index(ini+k));
				else
					inter(j) = inter(j) * ...
					index(ini+k)/(1+index(ini+k));
       				end;
       			end;
   	 	elseif DATAKINDS(j) == 2
       			% This case means that this person has only RP observations
	        	gstart = ini + 1;
        		gend = ini + NALT;
        		group = index(gstart:gend);
        		group = exp(group);
        		denom = sum(group);
        		group = group ./ denom;
        		for k = gstart : gend;
		       		if YVEC(k) == 1 
            				inter(j) = group(k - ini);
         			 end;
      			end;
       		else
       			% This case means that this person has both RP and SP observations
       			gstart = ini + 1;
       			gend = ini + NALT;
       			group = index(gstart:gend);
       			group = exp(group);
       			denom = sum(group);
       			group = group ./ denom;
       			for k = gstart : gend;
       				if YVEC(k) == 1
       					inter(j) = group(k - ini);
       				end;
       			end;
       			% For persons with both RP and SP observations, the first NALT
       			% observations are RP ones. Now we begin to calculate the
       			% conditional probability of SP observations from jth person 	
       			for k = 1 : (TIMES(j) - NALT);
       				index(gend+k) = exp(-1*index(gend+k));
       				if YVEC(gend+k) == 1
       					inter(j) = inter(j)/(1+index(gend+k));
				else
					inter(j) = inter(j) * ...
					index(gend+k)/(1+index(gend+k));
       				end;
       			end;
       		end;
       		%% Change the pointer to the next person %%
      	 	ini = ini + TIMES(j);
   	 end;
	 %% Summing conditional probabilities across random draws %%
   	 pn = pn + inter;
end;

%% Using average to approximate the integration %%
pn = pn / REPTITION;
lnpn = log(pn);
lnpn = WEIGHTS .* lnpn; 
f = -1 * sum(lnpn);

	
			
