
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code implements the nonparametric quantitle
% regression on the field measurement data, to construct
% time variables used in estimation.  

% Jia Yan 11/08/2004
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;

% Declare global which indicates the percentile you want to estimate 
global P;

% The disribution of the estimator is calculated based on bootstraping.
% nloops indicates the number of bootstrap draws.  
nloop = 100;

% load the data 
load floating.txt;
data=floating;
date=data(:,1);
x=data(:,2); % time of day  
y=data(:,3); % observed time saving

% Set the bandwidth
h = 0.8;

% Get the mean estimates for median time savine and dispersion of time saving 
points=linspace(4, 10, 601)';
P = 0.5;
bloclin1 = qreg(points, x, y, h);	
P = 0.8;
bloclin2 = qreg(points, x, y, h);	
disper = bloclin2(:,2) - bloclin1(:,2); 


% To construct the distribution of above twp estimates by paired bootstrap
data = [x, y];
num = length(x);
for iloop = 1:nloop;
	% For each loop, draw the pair (y,x) with replacement to get the bootstrap data
	sdata = zeros(num, 2);
	for i = 1:num;
		ind = floor(rand(1,1) * num + 1);
		sdata(i,:) = data(ind,:);
	end;  
	sdata = sortrows(sdata,1);
	sx = sdata(:,1);
	sy = sdata(:,2);
	
	% For each bootstrap data set, estimate median and 80% percentile respectively 
	for i = 1:2; 
		if i == 1
			P = 0.5;
			bloclin1 = qreg(points, sx, sy, h);	
		else
			P = 0.8;
			bloclin2 = qreg(points, sx, sy, h);
		end;
	end;
	if iloop == 1
		res_50 = bloclin1(:,2);
		res_80 = bloclin2(:,2);
	else
		res_50 = [res_50, bloclin1(:,2)];
		res_80 = [res_80, bloclin2(:,2)];
	end
    iloop
end;
