function out = qreg(points,x,y,h);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function implements local quantile regression. The inputs are:
% points: The discretized ponits for the x-space;
% x: the regressor -- time of day;
% y: the dependent variable -- time saving of using express lanes;
% h: the specified bandwidth;

% Jia Yan
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	% The percentile to be estimated
	global P;
	n = length(points);	
	const = ones(length(x),1);
	out = zeros(n,2);
	for i = 1:n;
	
	   % To get the right data ponits controled by the bandwith  	
	   a = -.5*sign( abs( (points(i,1)*const - x)/h ) -1 ) + .5; 
	   tempp0=nonzeros(x.*a);
	   tempp1=nonzeros(y.*a);
	   
	   % Get the weights to reweight the data points 
	   xandy =[tempp0,tempp1];                                                   
	   ztheta = xandy(:,1);   
	   yuse = xandy(:,2);
	   q1 = (ztheta - points(i,1));
	   nt2 = ( (ztheta- points(i,1))/h );
	   weights = (15/16)* ( 1-(nt2.^2)).^2;
	   
	   % Write data onto disk for optimization purpose
	   tempp2=ones(length(ztheta),1);     
	   tempp3 = [tempp2, q1];
	   save tempp3.txt tempp3 -ASCII;
	   save yuse.txt yuse -ASCII;
	   save weights.txt weights -ASCII;
	   
	   % Local linear quantile regerssion (see equation A1)
	   b0 = inv(tempp3'*tempp3)*tempp3'*yuse; % initial guess for the parameters
	   options=optimset('MaxFunEvals',3000000000);                                             
	   bhat=fminsearch('lae', b0, options);
	   save bhat.txt bhat -ASCII;
	   out(i,:)= [points(i,1), bhat(1)];
	   clear xandy ztheta yuse b xb resid obf w tp1 tp2 bhat;
	end;

